package com.citygis.server.manage.domain.controller.web;

import com.citygis.server.manage.domain.controller.co.template.TemplateCO;
import com.citygis.server.manage.domain.controller.vo.template.TemplateGetVO;
import com.citygis.server.manage.domain.controller.vo.template.TemplateListVO;
import com.citygis.server.manage.domain.dao.po.TemplatePO;
import com.citygis.server.manage.domain.facade.FeignService;
import com.citygis.server.manage.domain.facade.dto.TemplateDTO;
import com.citygis.server.manage.domain.factory.mapper.TemplateFactoryMapper;
import com.citygis.server.manage.domain.service.TemplateService;
import com.citygis.server.manage.domain.controller.co.template.TemplateQueryCO;
import com.citygis.server.manage.domain.controller.vo.template.TemplatePageVO;
import com.citygis.common.boot.struct.Result;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import jakarta.annotation.Resource;
import java.util.List;

@RestController
@Api("")
@RequestMapping("/template")
public class TemplateController {
    @Resource
    private TemplateService templateService;
    @Resource
    private FeignService feignService;

    @PostMapping("/feign")
    public Result<TemplateDTO> templateFeign(@RequestBody TemplateQueryCO co) {
        return Result.success(feignService.getTemplate(co));
    }

    @PostMapping("/page")
    public Result<List<TemplatePageVO>> pageTemplate(@RequestBody TemplateQueryCO co) {
        PageInfo<TemplatePO> pageInfo = templateService.pageTemplate(co);
        List<TemplatePageVO> templatePageVOList = TemplateFactoryMapper.INSTANCE.poToPageVOList(pageInfo.getList());
        return Result.success(templatePageVOList);
    }

    @PostMapping("/list")
    public Result<List<TemplateListVO>> listTemplate(@RequestBody TemplateQueryCO co) {
        return Result.success(templateService.listTemplate(co));
    }

    @PostMapping("/get")
    public Result<TemplateGetVO> getTemplate(@RequestBody TemplateQueryCO co) {
        return Result.success(templateService.getTemplate(co));
    }

    @PostMapping("/insert")
    public Result<Integer> insertTemplate(@RequestBody TemplateCO co) {
        return Result.success(templateService.insertTemplate(co));
    }

    @PostMapping("/modify")
    public Result<Integer> modifyTemplate(@RequestBody TemplateCO co) {
        return Result.success(templateService.modifyTemplate(co));
    }

    @PostMapping("/delete")
    public Result<Integer> deleteTemplate(@RequestBody TemplateCO co) {
        return Result.success(templateService.deleteTemplate(co));
    }
}
